@@ -19,21 +19,27 @@
 
 #ifndef PRESS_DATA_H
 #define PRESS_DATA_H
-#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include "slot.h"
 
 typedef struct {
   gint xoffset;
   gint yoffset;
+  gint width;
+  gint height;
   GdkPixmap *moving_pixmap;
   GdkBitmap *moving_mask;
-  GList* cards;
+  GList *cards;
   hslot_type hslot;
   gint cardid;
   gint status;
   GdkWindow *moving_cards;
+  GdkWindow *highlight_window;
 } press_data_type;
 
-void generate_press_data ( void );
-void free_press_data ( void );
+extern press_data_type *press_data;
+
+void create_press_data (GdkWindow * window);
+void generate_press_data (void);
+void free_press_data (void);
 #endif
