@@ -2,7 +2,7 @@
  * @file   ggz.h
  * @author Brent M. Hendricks
  * @date   Fri Nov  2 23:32:17 2001
- * $Id: ggz.h,v 1.1 2006/10/14 10:27:47 andreasr Exp $
+ * $Id: ggz.h,v 1.4 2006/11/06 21:18:53 andreasr Exp $
  * 
  * Header file for ggz components lib
  *
@@ -53,12 +53,14 @@ extern "C" {
 #endif
 
 #if defined __GNUC__ && (__GNUC__ >= 3)
-#  define _GGZFUNCTION_
+#  define _GGZFUNCTION_ "" 
+#elif defined(__sun)
+#  define _GGZFUNCTION_ ""
 #else
 #  ifndef __cplusplus
 #    define _GGZFUNCTION_ __FUNCTION__
 #  else
-#    define _GGZFUNCTION_
+#    define _GGZFUNCTION_ ""
 #  endif
 #endif
 
