@@ -30,12 +30,15 @@
 #define KEY_DIR "/apps/gnibbles"
 #define KEY_PREFERENCES_DIR "/apps/gnibbles/preferences"
 #define KEY_NUM_WORMS "/apps/gnibbles/preferences/players"
+#define KEY_NUM_AI "/apps/gnibbles/preferences/ai"
 #define KEY_SPEED "/apps/gnibbles/preferences/speed"
 #define KEY_FAKES "/apps/gnibbles/preferences/fakes"
 #define KEY_RANDOM "/apps/gnibbles/preferences/random"
 #define KEY_START_LEVEL "/apps/gnibbles/preferences/start_level"
 #define KEY_SOUND "/apps/gnibbles/preferences/sound"
 #define KEY_TILE_SIZE "/apps/gnibbles/preferences/tile_size"
+#define KEY_HEIGHT "/apps/gnibbles/preferences/height"
+#define KEY_WIDTH "/apps/gnibbles/preferences/width"
 
 #define KEY_WORM_DIR "/apps/gnibbles/preferences/worm/%d"
 #define KEY_WORM_COLOR "/apps/gnibbles/preferences/worm/%d/color"
@@ -46,31 +49,36 @@
 #define KEY_WORM_RIGHT "/apps/gnibbles/preferences/worm/%d/key_right"
 
 typedef struct {
-	gint color;
-	gboolean relmove;
-	gchar *up, *down, *left, *right;
+  gint color;
+  gboolean relmove;
+  gchar *up, *down, *left, *right;
 } GnibblesWormProps;
 
 typedef struct {
-	gint numworms;
-	gint gamespeed;
-	gint fakes;
-	gint random;
-	gint startlevel;
-	gint sound;
-	gint tilesize;
-	GnibblesWormProps *wormprops[NUMWORMS];
+  gint numworms;
+  gint human;
+  gint ai;
+  gint gamespeed;
+  gint fakes;
+  gint random;
+  gint startlevel;
+  gint sound;
+  gint tilesize;
+  gint height;
+  gint width;
+  GnibblesWormProps *wormprops[NUMWORMS];
 } GnibblesProperties;
 
 GnibblesProperties *gnibbles_properties_new (void);
 
 void gnibbles_properties_update (GnibblesProperties * tmp);
 
-void gnibbles_properties_destroy (GnibblesProperties *props);
+void gnibbles_properties_destroy (GnibblesProperties * props);
 
-GnibblesProperties *gnibbles_properties_copy (GnibblesProperties *props);
+GnibblesProperties *gnibbles_properties_copy (GnibblesProperties * props);
 
 void gnibbles_properties_set_worms_number (gint value);
+void gnibbles_properties_set_ai_number (gint value);
 void gnibbles_properties_set_speed (gint value);
 void gnibbles_properties_set_fakes (gboolean value);
 void gnibbles_properties_set_random (gboolean value);
@@ -79,12 +87,13 @@ void gnibbles_properties_set_sound (gboolean value);
 void gnibbles_properties_set_tile_size (gint value);
 void gnibbles_properties_set_worm_relative_movement (gint i, gboolean value);
 void gnibbles_properties_set_worm_color (gint i, gint value);
-void gnibbles_properties_set_worm_up (gint i, gchar *value);
-void gnibbles_properties_set_worm_down (gint i, gchar *value);
-void gnibbles_properties_set_worm_left (gint i, gchar *value);
+void gnibbles_properties_set_worm_up (gint i, gchar * value);
+void gnibbles_properties_set_worm_down (gint i, gchar * value);
+void gnibbles_properties_set_worm_left (gint i, gchar * value);
+void gnibbles_properties_set_worm_right (gint i, gchar * value);
+void gnibbles_properties_set_height (gint value);
+void gnibbles_properties_set_width (gint value);
 
-void gnibbles_properties_set_worm_right (gint i, gchar *value);
-
-void gnibbles_properties_save (GnibblesProperties *props);
+void gnibbles_properties_save (GnibblesProperties * props);
 
 #endif
