@@ -477,8 +477,8 @@ Tetris::initOptions ()
 	startingLevel = gconfGetInt (gconf_client, KEY_STARTING_LEVEL, 1);
 	if (startingLevel < 1) 
 		startingLevel = 1;
-	if (startingLevel > 10) 
-		startingLevel = 10;
+	if (startingLevel > 20) 
+		startingLevel = 20;
 
 	if (gconfGetBoolean (gconf_client, KEY_SOUND, TRUE)) 
 		sound->turnOn ();
@@ -785,8 +785,8 @@ Tetris::gameProperties(GtkAction *action, void *d)
 			  (GtkAttachOptions) 0,
 			  0, 0);
 
-	adj = gtk_adjustment_new (t->startingLevel, 1, 10, 1, 5, 10);
-	t->sentry = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 10, 0);
+	adj = gtk_adjustment_new (t->startingLevel, 1, 20, 1, 5, 20);
+	t->sentry = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 10.0, 0);
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (t->sentry),
 					   GTK_UPDATE_ALWAYS);
 	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (t->sentry), TRUE);
@@ -842,7 +842,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
  	gtk_box_pack_start (GTK_BOX (fvbox), t->rotate_counter_clock_wise_toggle,
 			    0, 0, 0);
 
-	t->useTargetToggle = gtk_check_button_new_with_mnemonic (_("Show where the block will _land"));
+	t->useTargetToggle = gtk_check_button_new_with_mnemonic (_("Show _where the block will land"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (t->useTargetToggle), 
 				      t->useTarget);
 	g_signal_connect (t->useTargetToggle, "clicked",
@@ -1437,16 +1437,26 @@ Tetris::gameAbout(GtkAction *action, void *d)
 
 	const gchar * const authors[] = { "J. Marcin Gorycki", NULL };
 
+	const gchar * const documenters[] = { "Angela Boyle", NULL };
+
+	gchar *license = games_get_license (_("Gnometris"));
+
 	gtk_show_about_dialog (GTK_WINDOW (t->getWidget()),
 			       "name", _("Gnometris"),
 			       "version", VERSION,
 			       "comments", _("Written for my wife, Matylda\n"
 					     "Send comments and bug reports to: \n"
 					     "janusz.gorycki@intel.com"),
-				"copyright", "Copyright \xc2\xa9 2000 J. Marcin Gorycki",
-				"authors", authors,				
-				"translator_credits", _("translator-credits"),
-				NULL);
+			       "copyright", "Copyright \xc2\xa9 1999-2006 J. Marcin Gorycki",
+			       "license", license,
+			       "authors", authors,
+			       "documenters", documenters,				
+			       "translator_credits", _("translator-credits"),
+			       "logo-icon-name", "gnome-gnometris",
+			       "website", "http://www.gnome.org/projects/gnome-games/",
+			       "wrap-license", TRUE,
+			       NULL);
+	g_free (license);
 
 	return TRUE;
 }
