@@ -29,11 +29,12 @@
 
 #include "games-card-pixmaps.h"
 
-G_DEFINE_TYPE(GamesCardPixmaps, games_card_pixmaps, GAMES_TYPE_CARD_IMAGES);
+G_DEFINE_TYPE (GamesCardPixmaps, games_card_pixmaps, GAMES_TYPE_CARD_IMAGES);
 
-GamesCardPixmaps * games_card_pixmaps_new (GdkWindow * drawable)
+GamesCardPixmaps *
+games_card_pixmaps_new (GdkWindow * drawable)
 {
-  GamesCardPixmaps * images;
+  GamesCardPixmaps *images;
 
   images = g_object_new (GAMES_TYPE_CARD_PIXMAPS, NULL);
 
@@ -42,35 +43,42 @@ GamesCardPixmaps * games_card_pixmaps_new (GdkWindow * drawable)
   return images;
 }
 
-GdkPixmap * games_card_pixmaps_get_card_by_id (GamesCardPixmaps * images,
-					      gint cardid)
+GdkPixmap *
+games_card_pixmaps_get_card_by_id (GamesCardPixmaps * images, gint cardid)
 {
-  GdkPixbuf * pixbuf;
+  GdkPixbuf *pixbuf;
   gint width, height;
 
-  g_return_val_if_fail (((cardid >= 0) && (cardid < GAMES_CARDS_TOTAL)), NULL);
+  g_return_val_if_fail (((cardid >= 0)
+			 && (cardid < GAMES_CARDS_TOTAL)), NULL);
 
   if (images->pixmaps[cardid])
     return images->pixmaps[cardid];
 
-  pixbuf = games_card_images_get_card_by_id (GAMES_CARD_IMAGES (images), cardid);
+  pixbuf =
+    games_card_images_get_card_by_id (GAMES_CARD_IMAGES (images), cardid);
   width = images->parent.width;
   height = images->parent.height;
 
   if (images->mask) {
-    images->pixmaps[cardid] = gdk_pixmap_new (images->drawable, width, height, -1);
-    gdk_draw_pixbuf (images->pixmaps[cardid], NULL, pixbuf, 0, 0, 0, 0, width, height, 
-		     GDK_RGB_DITHER_NORMAL, 0, 0);
+    images->pixmaps[cardid] =
+      gdk_pixmap_new (images->drawable, width, height, -1);
+    gdk_draw_pixbuf (images->pixmaps[cardid], NULL, pixbuf, 0, 0, 0, 0, width,
+		     height, GDK_RGB_DITHER_NORMAL, 0, 0);
   } else {
-    gdk_pixbuf_render_pixmap_and_mask_for_colormap (pixbuf, 
-						    gdk_colormap_get_system(),
-						    &(images->pixmaps[cardid]), &(images->mask), 127);
+    gdk_pixbuf_render_pixmap_and_mask_for_colormap (pixbuf,
+						    gdk_colormap_get_system
+						    (),
+						    &(images->
+						      pixmaps[cardid]),
+						    &(images->mask), 127);
   }
 
   return images->pixmaps[cardid];
 }
 
-GdkBitmap * games_card_pixmaps_get_mask (GamesCardPixmaps * images)
+GdkBitmap *
+games_card_pixmaps_get_mask (GamesCardPixmaps * images)
 {
   if (!images->mask) {
     /* Force the mask to be drawn and choose the most likely card to be drawn
@@ -81,39 +89,42 @@ GdkBitmap * games_card_pixmaps_get_mask (GamesCardPixmaps * images)
   return images->mask;
 }
 
-GdkPixmap * games_card_pixmaps_get_card (GamesCardPixmaps * images, gint suit, 
-					gint rank)
+GdkPixmap *
+games_card_pixmaps_get_card (GamesCardPixmaps * images, gint suit, gint rank)
 {
-  g_return_val_if_fail (((suit >= GAMES_CARDS_CLUBS) && 
-		         (suit <= GAMES_CARDS_SPADES)),
-			NULL);
-  g_return_val_if_fail (((rank >= GAMES_CARD_ACE) && 
-		         (rank <= GAMES_CARD_ACE_HIGH)),
-			NULL);
+  g_return_val_if_fail (((suit >= GAMES_CARDS_CLUBS) &&
+			 (suit <= GAMES_CARDS_SPADES)), NULL);
+  g_return_val_if_fail (((rank >= GAMES_CARD_ACE) &&
+			 (rank <= GAMES_CARD_ACE_HIGH)), NULL);
 
-  return games_card_pixmaps_get_card_by_id (images, GAMES_CARD_ID(suit, rank));
+  return games_card_pixmaps_get_card_by_id (images,
+					    GAMES_CARD_ID (suit, rank));
 }
 
-GdkPixmap * games_card_pixmaps_get_red_joker (GamesCardPixmaps * images)
+GdkPixmap *
+games_card_pixmaps_get_red_joker (GamesCardPixmaps * images)
 {
-  return games_card_pixmaps_get_card_by_id (images, GAMES_CARD_BACK);
+  return games_card_pixmaps_get_card_by_id (images, GAMES_CARD_RED_JOKER);
 }
 
-GdkPixmap * games_card_pixmaps_get_black_joker (GamesCardPixmaps * images)
+GdkPixmap *
+games_card_pixmaps_get_black_joker (GamesCardPixmaps * images)
 {
   return games_card_pixmaps_get_card_by_id (images, GAMES_CARD_BLACK_JOKER);
 }
 
-GdkPixmap * games_card_pixmaps_get_back (GamesCardPixmaps * images)
+GdkPixmap *
+games_card_pixmaps_get_back (GamesCardPixmaps * images)
 {
   return games_card_pixmaps_get_card_by_id (images, GAMES_CARD_BACK);
 }
 
-static void games_card_pixmaps_purge (GamesCardPixmaps * images)
+static void
+games_card_pixmaps_purge (GamesCardPixmaps * images)
 {
   int i;
 
-  for (i=0; i<GAMES_CARDS_TOTAL; i++) {
+  for (i = 0; i < GAMES_CARDS_TOTAL; i++) {
     if (images->pixmaps[i]) {
       g_object_unref (images->pixmaps[i]);
       images->pixmaps[i] = NULL;
@@ -126,32 +137,37 @@ static void games_card_pixmaps_purge (GamesCardPixmaps * images)
   }
 }
 
-void games_card_pixmaps_set_size (GamesCardPixmaps * images, 
-				 gint width, gint height)
+void
+games_card_pixmaps_set_size (GamesCardPixmaps * images,
+			     gint width, gint height)
 {
   games_card_images_set_size (&images->parent, width, height);
   games_card_pixmaps_purge (images);
 }
 
-void games_card_pixmaps_set_theme (GamesCardPixmaps * images, gchar * name)
+void
+games_card_pixmaps_set_theme (GamesCardPixmaps * images, gchar * name)
 {
   games_card_images_set_theme (&images->parent, name);
   games_card_pixmaps_purge (images);
 }
 
-static void games_card_pixmaps_finalize (GamesCardPixmaps * images)
+static void
+games_card_pixmaps_finalize (GamesCardPixmaps * images)
 {
   games_card_pixmaps_purge (images);
 }
 
-static void games_card_pixmaps_class_init (GamesCardPixmapsClass *class)
+static void
+games_card_pixmaps_class_init (GamesCardPixmapsClass * class)
 {
   GObjectClass *oclass = G_OBJECT_CLASS (class);
 
   oclass->finalize = (GObjectFinalizeFunc) games_card_pixmaps_finalize;
 }
 
-static void games_card_pixmaps_init (GamesCardPixmaps *cardimages)
+static void
+games_card_pixmaps_init (GamesCardPixmaps * cardimages)
 {
   cardimages->pixmaps = g_new0 (GdkPixmap *, GAMES_CARDS_TOTAL);
   cardimages->mask = NULL;
